pub struct IterRef<'a, T>where
T: 'static,{ /* private fields */ }Expand description
A reference to a single element of T.
Use get(field) to access a single field.
Implementations
Sourceimpl<'a, T> IterRef<'a, T>
impl<'a, T> IterRef<'a, T>
Sourcepub fn get<const NAME: &'static str, V: 'static>(&self) -> &V
pub fn get<const NAME: &'static str, V: 'static>(&self) -> &V
Get a specified field of T.
Compile errors
- Fails to compile if the requested field does not exist.
- Fails to compile if the requested type does not match the found field (by size).
It needs the correct type or it fails to compile
ⓘ
#![allow(incomplete_features)]
#![feature(generic_const_exprs)]
use multi_array_list::MultiArrayList;
struct Point {
x: i32,
y: i32,
}
let mut points = MultiArrayList::<Point>::new();
points.push(Point { x: 1, y: 0 });
for point in points.iter() {
point.get::<"x", bool>();
}Auto Trait Implementations
impl<'a, T> Freeze for IterRef<'a, T>
impl<'a, T> RefUnwindSafe for IterRef<'a, T>where
T: RefUnwindSafe,
impl<'a, T> !Send for IterRef<'a, T>
impl<'a, T> !Sync for IterRef<'a, T>
impl<'a, T> Unpin for IterRef<'a, T>
impl<'a, T> UnsafeUnpin for IterRef<'a, T>
impl<'a, T> UnwindSafe for IterRef<'a, T>where
T: RefUnwindSafe,